
# GRIDLib

<div align="center">

[![PyPI - Version](https://img.shields.io/pypi/v/gridlib.svg)](https://pypi.python.org/pypi/gridlib)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/gridlib.svg)](https://pypi.python.org/pypi/gridlib)
[![Tests](https://github.com/boydcpeters/gridlib/workflows/tests/badge.svg)](https://github.com/boydcpeters/gridlib/actions?workflow=tests)
[![Codecov](https://codecov.io/gh/boydcpeters/gridlib/branch/main/graph/badge.svg)](https://codecov.io/gh/boydcpeters/gridlib)
[![Read the Docs](https://readthedocs.org/projects/gridlib/badge/)](https://gridlib.readthedocs.io/)
[![PyPI - License](https://img.shields.io/pypi/l/gridlib.svg)](https://pypi.python.org/pypi/gridlib)

[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.0-4baaaa.svg)](https://www.contributor-covenant.org/version/2/0/code_of_conduct/)

</div>

Python package to perform GRID analysis on fluorescence survival time distributions.

* GitHub repo: <https://github.com/boydcpeters/gridlib.git>
* Documentation: <https://gridlib.readthedocs.io>
* Free software: GNU General Public License v3

## Features

* TODO

## Quickstart

TODO

## References

The GRID fitting procedure implemented in this package is based on the following paper:

```latex
@article{reisser2020inferring,
  title={Inferring quantity and qualities of superimposed reaction rates from single molecule survival time distributions},
  author={Reisser, Matthias and Hettich, Johannes and Kuhn, Timo and Popp, Achim P and Gro{\ss}e-Berkenbusch, Andreas and Gebhardt, J Christof M},
  journal={Scientific reports},
  volume={10},
  number={1},
  pages={1--13},
  year={2020},
  publisher={Nature Publishing Group}
}
```

## Credits

This package was created with [Cookiecutter][cookiecutter] and the [fedejaure/cookiecutter-modern-pypackage][cookiecutter-modern-pypackage] project template.

[cookiecutter]: https://github.com/cookiecutter/cookiecutter
[cookiecutter-modern-pypackage]: https://github.com/fedejaure/cookiecutter-modern-pypackage
